@@ -2,27 +2,12 @@
 """
 get_movie.py
 
-Usage: get_movie "imdbID"
+Usage: get_movie "movieID"
 
-Show some info about the movie with the given imdbID (e.g. '0133093'
-for "The Matrix".
+Show some info about the movie with the given movieID (e.g. '0133093'
+for "The Matrix", using 'http' or 'mobile').
+Notice that movieID, using 'sql', are not the same IDs used on the web.
 """
-# Parameters to initialize the IMDb class.
-IMDB_PARAMS = {
-    # The used access system. 'web' means that you're retrieving data
-    # from the IMDb web server.
-    'accessSystem': 'web'
-    #'accessSystem': 'mobile'
-    # XXX: if you've a local installation of the IMDb database,
-    # comment the above line and uncomment the following two.
-    #'accessSystem': 'local',
-    #'dbDirectory':  '/usr/local/imdb' # or, in a Windows environment:
-    #'dbDirectory':  'D:/imdb-20060107'
-
-    # XXX: parameters for a SQL installation.
-    #'accessSystem': 'sql',
-    #'uri': 'mysql://userName:yourPassword@localhost/dbName'
-}
 
 import sys
 
@@ -36,19 +21,19 @@ except ImportError:
 
 if len(sys.argv) != 2:
     print 'Only one argument is required:'
-    print '  %s "imdbID"' % sys.argv[0]
+    print '  %s "movieID"' % sys.argv[0]
     sys.exit(2)
 
-imdbID = sys.argv[1]
+movieID = sys.argv[1]
 
-i = imdb.IMDb(**IMDB_PARAMS)
+i = imdb.IMDb()
 
 out_encoding = sys.stdout.encoding or sys.getdefaultencoding()
 
 try:
     # Get a Movie object with the data about the movie identified by
-    # the given imdbID.
-    movie = i.get_movie(imdbID)
+    # the given movieID.
+    movie = i.get_movie(movieID)
 except imdb.IMDbError, e:
     print "Probably you're not connected to Internet.  Complete error report:"
     print e
@@ -56,7 +41,7 @@ except imdb.IMDbError, e:
 
 
 if not movie:
-    print 'It seems that there\'s no movie with imdbID "%s"' % imdbID
+    print 'It seems that there\'s no movie with movieID "%s"' % movieID
     sys.exit(4)
 
 # XXX: this is the easier way to print the main info about a movie;
@@ -72,7 +57,7 @@ print movie.summary().encode(out_encoding, 'replace')
 # This is only a short example; you can get a longer summary using
 # 'print movie.summary()' and the complete set of information looking for
 # the output of the movie.keys() method.
-#print '==== "%s" / imdbID: %s ====' % (movie['title'], imdbID)
+#print '==== "%s" / movieID: %s ====' % (movie['title'], movieID)
 # XXX: use the IMDb instance to get the IMDb web URL for the movie.
 #imdbURL = i.get_imdbURL(movie)
 #if imdbURL:
