@@ -4,7 +4,7 @@ parser.http.utils module (imdb package).
 This module provides miscellaneous utilities used by
 the imdb.parser.http classes.
 
-Copyright 2004-2009 Davide Alberani <da@erlug.linux.it>
+Copyright 2004-2012 Davide Alberani <da@erlug.linux.it>
                2008 H. Turgut Uyar <uyar@tekir.org>
 
 This program is free software; you can redistribute it and/or modify
@@ -89,7 +89,7 @@ entitydefs = entitydefs.copy()
 entitydefsget = entitydefs.get
 entitydefs['nbsp'] = ' '
 
-sgmlentity = {'lt': '<', 'gt': '>', 'amp': '&', 'quot': '"', 'apos': '\''}
+sgmlentity = {'lt': '<', 'gt': '>', 'amp': '&', 'quot': '"', 'apos': '\'', 'ndash': '-'}
 sgmlentityget = sgmlentity.get
 _sgmlentkeys = sgmlentity.keys()
 
@@ -245,6 +245,7 @@ def build_person(txt, personID=None, billingPos=None,
         if lr == 1:
             role = role[0]
             roleID = roleID[0]
+            notes = roleNotes[0] or u''
     elif roleID is not None:
         roleID = str(roleID)
     if personID is not None:
@@ -263,14 +264,20 @@ def build_person(txt, personID=None, billingPos=None,
     return person
 
 
+_re_chrIDs = re.compile('[0-9]{7}')
+
 _b_m_logger = logging.getLogger('imdbpy.parser.http.build_movie')
 # To shrink spaces.
 re_spaces = re.compile(r'\s+')
 def build_movie(txt, movieID=None, roleID=None, status=None,
                 accessSystem='http', modFunct=None, _parsingCharacter=False,
-                _parsingCompany=False):
+                _parsingCompany=False, year=None, chrRoles=None,
+                rolesNoChar=None, additionalNotes=None):
     """Given a string as normally seen on the "categorized" page of
     a person on the IMDb's web site, returns a Movie instance."""
+    # FIXME: Oook, lets face it: build_movie and build_person are now
+    # two horrible sets of patches to support the new IMDb design.  They
+    # must be rewritten from scratch.
     if _parsingCharacter:
         _defSep = ' Played by '
     elif _parsingCompany:
@@ -288,10 +295,20 @@ def build_movie(txt, movieID=None, roleID=None, status=None,
         role = tsplit[1].lstrip()
     if title[-9:] == 'TV Series':
         title = title[:-9].rstrip()
+    #elif title[-7:] == '(short)':
+    #    title = title[:-7].rstrip()
+    #elif title[-11:] == '(TV series)':
+    #    title = title[:-11].rstrip()
+    #elif title[-10:] == '(TV movie)':
+    #    title = title[:-10].rstrip()
     elif title[-14:] == 'TV mini-series':
         title = title[:-14] + ' (mini)'
+    if title and title.endswith(_defSep.rstrip()):
+        title = title[:-len(_defSep)+1]
     # Try to understand where the movie title ends.
     while True:
+        if year:
+            break
         if title[-1:] != ')':
             # Ignore the silly "TV Series" notice.
             if title[-9:] == 'TV Series':
@@ -313,19 +330,32 @@ def build_movie(txt, movieID=None, roleID=None, status=None,
         if (first4.isdigit() or first4 == '????') and \
                 title[nidx+5:nidx+6] in (')', '/'): break
         # The last item in parentheses is a known kind: stop here.
-        if title[nidx+1:-1] in ('TV', 'V', 'mini', 'VG'): break
+        if title[nidx+1:-1] in ('TV', 'V', 'mini', 'VG', 'TV movie',
+                'TV series', 'short'): break
         # Else, in parentheses there are some notes.
         # XXX: should the notes in the role half be kept separated
         #      from the notes in the movie title half?
         if notes: notes = '%s %s' % (title[nidx:], notes)
         else: notes = title[nidx:]
         title = title[:nidx].rstrip()
+    if year:
+        year = year.strip()
+        if title[-1] == ')':
+            fpIdx = title.rfind('(')
+            if fpIdx != -1:
+                if notes: notes = '%s %s' % (title[fpIdx:], notes)
+                else: notes = title[fpIdx:]
+                title = title[:fpIdx].rstrip()
+        title = u'%s (%s)' % (title, year)
     if _parsingCharacter and roleID and not role:
         roleID = None
     if not roleID:
         roleID = None
     elif len(roleID) == 1:
         roleID = roleID[0]
+    if not role and chrRoles and isinstance(roleID, (str, unicode)):
+        roleID = _re_chrIDs.findall(roleID)
+        role = ' / '.join(filter(None, chrRoles.split('@@')))
     # Manages multiple roleIDs.
     if isinstance(roleID, list):
         tmprole = role.split('/')
@@ -356,13 +386,31 @@ def build_movie(txt, movieID=None, roleID=None, status=None,
         movieID = str(movieID)
     if (not title) or (movieID is None):
         _b_m_logger.error('empty title or movieID for "%s"', txt)
+    if rolesNoChar:
+        rolesNoChar = filter(None, [x.strip() for x in rolesNoChar.split('/')])
+        if not role:
+            role = []
+        elif not isinstance(role, list):
+            role = [role]
+        role += rolesNoChar
+    notes = notes.strip()
+    if additionalNotes:
+        additionalNotes = re_spaces.sub(' ', additionalNotes).strip()
+        if notes:
+            notes += u' '
+        notes += additionalNotes
+    if role and isinstance(role, list) and notes.endswith(role[-1].replace('\n', ' ')):
+        role = role[:-1]
     m = Movie(title=title, movieID=movieID, notes=notes, currentRole=role,
                 roleID=roleID, roleIsPerson=_parsingCharacter,
                 modFunct=modFunct, accessSystem=accessSystem)
     if roleNotes and len(roleNotes) == len(roleID):
         for idx, role in enumerate(m.currentRole):
-            if roleNotes[idx]:
-                role.notes = roleNotes[idx]
+            try:
+                if roleNotes[idx]:
+                    role.notes = roleNotes[idx]
+            except IndexError:
+                break
     # Status can't be checked here, and must be detected by the parser.
     if status:
         m['status'] = status
@@ -407,7 +455,7 @@ class DOMParserBase(object):
                     self._is_xml_unicode = True
                     self.usingModule = 'beautifulsoup'
                 else:
-                    warnings.warn('unknown module "%s"' % mod)
+                    self._logger.warn('unknown module "%s"' % mod)
                     continue
                 self.fromstring = fromstring
                 self._tostring = tostring
@@ -418,14 +466,14 @@ class DOMParserBase(object):
                 if idx+1 >= nrMods:
                     # Raise the exception, if we don't have any more
                     # options to try.
-                    raise IMDbError, 'unable to use any parser in %s: %s' % \
-                                    (str(useModule), str(e))
+                    raise IMDbError('unable to use any parser in %s: %s' % \
+                                    (str(useModule), str(e)))
                 else:
                     warnings.warn('unable to use "%s": %s' % (mod, str(e)))
                     _gotError = True
                 continue
         else:
-            raise IMDbError, 'unable to use parsers in %s' % str(useModule)
+            raise IMDbError('unable to use parsers in %s' % str(useModule))
         # Fall-back defaults.
         self._modFunct = None
         self._as = 'http'
@@ -465,12 +513,17 @@ class DOMParserBase(object):
         # Temporary fix: self.parse_dom must work even for empty strings.
         html_string = self.preprocess_string(html_string)
         html_string = html_string.strip()
-        # tag attributes like title="&#x22;Family Guy&#x22;" will be
-        # converted to title=""Family Guy"" and this confuses BeautifulSoup.
         if self.usingModule == 'beautifulsoup':
+            # tag attributes like title="&#x22;Family Guy&#x22;" will be
+            # converted to title=""Family Guy"" and this confuses BeautifulSoup.
             html_string = html_string.replace('""', '"')
+            # Browser-specific escapes create problems to BeautifulSoup.
+            html_string = html_string.replace('<!--[if IE]>', '"')
+            html_string = html_string.replace('<![endif]-->', '"')
+        #print html_string.encode('utf8')
         if html_string:
             dom = self.get_dom(html_string)
+            #print self.tostring(dom).encode('utf8')
             try:
                 dom = self.preprocess_dom(dom)
             except Exception, e:
@@ -549,6 +602,9 @@ class DOMParserBase(object):
         """Here we can modify the text, before it's parsed."""
         if not html_string:
             return html_string
+        # Remove silly &nbsp;&raquo; and &ndash; chars.
+        html_string = html_string.replace(u' \xbb', u'')
+        html_string = html_string.replace(u'&ndash;', u'-')
         try:
             preprocessors = self.preprocessors
         except AttributeError:
@@ -771,7 +827,7 @@ class GatherRefs(DOMParserBase):
                             'link': './@href',
                             'info': './following::text()[1]'
                             },
-        postprocess=lambda x: _parse_ref(x.get('text'), x.get('link'),
+        postprocess=lambda x: _parse_ref(x.get('text') or u'', x.get('link') or '',
                                          (x.get('info') or u'').strip()))]
     extractors = [
         Extractor(label='names refs',
@@ -794,6 +850,10 @@ class GatherRefs(DOMParserBase):
         for item in ('names refs', 'titles refs', 'characters refs'):
             result[item] = {}
             for k, v in data.get(item, []):
+                k = k.strip()
+                v = v.strip()
+                if not (k and v):
+                    continue
                 if not v.endswith('/'): continue
                 imdbID = analyze_imdbid(v)
                 if item == 'names refs':
