@@ -6,7 +6,7 @@ IMDb's data for mobile systems.
 the imdb.IMDb function will return an instance of this class when
 called with the 'accessSystem' argument set to "mobile".
 
-Copyright 2005-2010 Davide Alberani <da@erlug.linux.it>
+Copyright 2005-2011 Davide Alberani <da@erlug.linux.it>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,7 +27,6 @@ import re
 import logging
 from urllib import unquote
 
-from imdb import imdbURL_movie_main, imdbURL_person_main, imdbURL_character_main
 from imdb.Movie import Movie
 from imdb.utils import analyze_title, analyze_name, canonicalName, \
                         date_and_notes
@@ -52,6 +51,10 @@ re_imdbID = re.compile(r'(?<=nm|tt|ch)([0-9]{7})\b')
 # movie AKAs.
 re_makas = re.compile('(<p class="find-aka">.*?</p>)')
 
+# Remove episode numbers.
+re_filmo_episodes = re.compile('<div class="filmo-episodes">.*?</div>',
+        re.M | re.I)
+
 
 def _unHtml(s):
     """Return a string without tags and no multiple spaces."""
@@ -123,13 +126,15 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
     accessSystem = 'mobile'
     _mobile_logger = logging.getLogger('imdbpy.parser.mobile')
 
-    def __init__(self, isThin=1, *arguments, **keywords):
+    def __init__(self, isThin=0, *arguments, **keywords):
         self.accessSystem = 'mobile'
         IMDbHTTPAccessSystem.__init__(self, isThin, *arguments, **keywords)
 
     def _clean_html(self, html):
         """Normalize the retrieve html."""
         html = re_spaces.sub(' ', html)
+        # Remove silly &nbsp;&raquo; chars.
+        html = html.replace('&nbsp;&raquo;', '')
         return subXMLRefs(html)
 
     def _mretrieve(self, url, size=-1):
@@ -234,11 +239,13 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         return res
 
     def get_movie_main(self, movieID):
-        cont = self._mretrieve(imdbURL_movie_main % movieID + 'maindetails')
+        cont = self._mretrieve(self.urls['movie_main'] % movieID + 'maindetails')
         title = _findBetween(cont, '<title>', '</title>', maxRes=1)
         if not title:
-            raise IMDbDataAccessError, 'unable to get movieID "%s"' % movieID
+            raise IMDbDataAccessError('unable to get movieID "%s"' % movieID)
         title = _unHtml(title[0])
+        if title.endswith(' - IMDb'):
+            title = title[:-7]
         if cont.find('<span class="tv-extra">TV mini-series</span>') != -1:
             title += ' (mini)'
         d = analyze_title(title)
@@ -329,29 +336,26 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         if cvurl:
             cvurl = _findBetween(cvurl[0], 'src="', '"', maxRes=1)
             if cvurl: d['cover url'] = cvurl[0]
-        genres = _findBetween(cont, 'href="/Sections/Genres/', '/')
+        genres = _findBetween(cont, 'href="/genre/', '"')
         if genres:
             d['genres'] = list(set(genres))
-        ur = _findBetween(cont, '<div class="starbar-meta">', '</div>',
+        ur = _findBetween(cont, 'id="star-bar-user-rate">', '</div>',
                             maxRes=1)
         if ur:
             rat = _findBetween(ur[0], '<b>', '</b>', maxRes=1)
             if rat:
-                teni = rat[0].find('/10')
-                if teni != -1:
-                    rat = rat[0][:teni]
-                    try:
-                        rat = float(rat.strip())
-                        d['rating'] = rat
-                    except ValueError:
-                        self._mobile_logger.warn('wrong rating: %s', rat)
-            vi = ur[0].rfind('tn15more">')
+                if rat:
+                    d['rating'] = rat[0].strip()
+                else:
+                    self._mobile_logger.warn('wrong rating: %s', rat)
+            vi = ur[0].rfind('href="ratings"')
             if vi != -1 and ur[0][vi+10:].find('await') == -1:
                 try:
-                    votes = _unHtml(ur[0][vi+10:]).replace('votes', '').strip()
-                    votes = int(votes.replace(',', ''))
+                    votes = _findBetween(ur[0][vi:], "title='",
+                                        " IMDb", maxRes=1)
+                    votes = int(votes[0].replace(',', ''))
                     d['votes'] = votes
-                except ValueError:
+                except (ValueError, IndexError):
                     self._mobile_logger.warn('wrong votes: %s', ur)
         top250 = _findBetween(cont, 'href="/chart/top?', '</a>', maxRes=1)
         if top250:
@@ -393,9 +397,12 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         if akas:
             # For some reason, here <br> is still used in place of <br/>.
             akas[:] = [x for x in akas[0].split('<br>') if x.strip()]
-            akas = [_unHtml(x).replace(' (','::(', 1) for x in akas]
-            if 'more' in akas: akas.remove('more')
-            d['akas'] = akas
+            akas = [_unHtml(x).replace('" - ','::', 1).lstrip('"').strip()
+                    for x in akas]
+            if 'See more' in akas: akas.remove('See more')
+            akas[:] = [x for x in akas if x]
+            if akas:
+                d['akas'] = akas
         mpaa = _findBetween(cont, 'MPAA</a>:', '</div>', maxRes=1)
         if mpaa: d['mpaa'] = _unHtml(mpaa[0])
         runtimes = _findBetween(cont, 'Runtime:</h5>', '</div>', maxRes=1)
@@ -461,7 +468,7 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         return {'data': d}
 
     def get_movie_plot(self, movieID):
-        cont = self._mretrieve(imdbURL_movie_main % movieID + 'plotsummary')
+        cont = self._mretrieve(self.urls['movie_main'] % movieID + 'plotsummary')
         plot = _findBetween(cont, '<p class="plotpar">', '</p>')
         plot[:] = [_unHtml(x) for x in plot]
         for i in xrange(len(plot)):
@@ -471,8 +478,6 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
                 plot[i] = '%s::%s' % \
                         (p[:wbyidx].rstrip(),
                     p[wbyidx+12:].rstrip().replace('{','<').replace('}','>'))
-            else:
-                plot[i] = '%s::Anonymous' % p
         if plot: return {'data': {'plot': plot}}
         return {'data': {}}
 
@@ -524,60 +529,73 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
 
     def get_person_main(self, personID, _parseChr=False):
         if not _parseChr:
-            url = imdbURL_person_main % personID + 'maindetails'
+            url = self.urls['person_main'] % personID + 'maindetails'
         else:
-            url = imdbURL_character_main % personID
+            url = self.urls['character_main'] % personID
         s = self._mretrieve(url)
         r = {}
         name = _findBetween(s, '<title>', '</title>', maxRes=1)
         if not name:
             if _parseChr: w = 'characterID'
             else: w = 'personID'
-            raise IMDbDataAccessError, 'unable to get %s "%s"' % (w, personID)
-        name = _unHtml(name[0])
+            raise IMDbDataAccessError('unable to get %s "%s"' % (w, personID))
+        name = _unHtml(name[0].replace(' - IMDb', ''))
         if _parseChr:
             name = name.replace('(Character)', '').strip()
             name = name.replace('- Filmography by type', '').strip()
         else:
             name = name.replace('- Filmography by', '').strip()
         r = analyze_name(name, canonical=not _parseChr)
-        for dKind in ('birth', 'death'):
-            date = _findBetween(s, '<h5>Date of %s:</h5>' % dKind.capitalize(),
-                                ('<a class', '</div>', '<br/><br/>'), maxRes=1)
+        for dKind in ('Born', 'Died'):
+            date = _findBetween(s, '%s:</h4>' % dKind.capitalize(),
+                                ('<div class', '</div>', '<br/><br/>'), maxRes=1)
             if date:
                 date = _unHtml(date[0])
                 if date:
-                    date, notes = date_and_notes(date)
+                    #date, notes = date_and_notes(date)
+                    # TODO: fix to handle real names.
+                    date_notes = date.split(' in ', 1)
+                    notes = u''
+                    date = date_notes[0]
+                    if len(date_notes) == 2:
+                        notes = date_notes[1]
+                    dtitle = 'birth'
+                    if dKind == 'Died':
+                        dtitle = 'death'
                     if date:
-                        r['%s date' % dKind] = date
+                        r['%s date' % dtitle] = date
                     if notes:
-                        r['%s notes' % dKind] = notes
-        akas = _findBetween(s, 'Alternate Names:</h5>', ('</div>',
+                        r['%s notes' % dtitle] = notes
+        akas = _findBetween(s, 'Alternate Names:</h4>', ('</div>',
                             '<br/><br/>'), maxRes=1)
         if akas:
             akas = akas[0]
+            if akas:
+                akas = _unHtml(akas)
             if akas.find(' | ') != -1:
-                akas = _unHtml(akas).split(' | ')
+                akas = akas.split(' | ')
             else:
-                akas = _unHtml(akas).split(' / ')
-            if akas: r['akas'] = akas
-        hs = _findBetween(s, 'name="headshot"', '</a>', maxRes=1)
+                akas = akas.split(' / ')
+            if akas: r['akas'] = filter(None, [x.strip() for x in akas])
+        hs = _findBetween(s, "rel='image_src'", '>', maxRes=1)
+        if not hs:
+            hs = _findBetween(s, 'rel="image_src"', '>', maxRes=1)
+        if not hs:
+            hs = _findBetween(s, '<a name="headshot"', '</a>', maxRes=1)
         if hs:
-            hs[:] = _findBetween(hs[0], 'src="', '"', maxRes=1)
-            if hs: r['headshot'] = hs[0]
+            hsl = _findBetween(hs[0], "href='", "'", maxRes=1)
+            if not hsl:
+                hsl = _findBetween(hs[0], 'href="', '"', maxRes=1)
+            if hsl and 'imdb-share-logo' not in hsl[0]:
+                r['headshot'] = hsl[0]
         # Build a list of tuples such [('hrefLink', 'section name')]
-        workkind = _findBetween(s, '<div class="strip jump">', '</div>',
-                                maxRes=1)
-        if workkind:
-            workkind[:] = _findBetween(workkind[0], 'href="#', '</a>')
-        else:
-            # Assume there's only one section and/or there are no
-            # section links, for some reason.
-            workkind[:] = _findBetween(s, '<h5><a name=', '</a></h5>')
-            workkind[:] = [x.lstrip('"').rstrip(':').lower() for x in workkind]
+        workkind = _findBetween(s, 'id="jumpto_', '</a>')
         ws = []
         for work in workkind:
-            wsplit = work.split('">', 1)
+            sep = '" >'
+            if '">' in work:
+                sep = '">'
+            wsplit = work.split(sep, 1)
             if len(wsplit) == 2:
                 sect = wsplit[0]
                 if '"' in sect:
@@ -590,6 +608,8 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         #    ws.append(('filmography', 'filmography'))
         for sect, sectName in ws:
             raws = u''
+            if sectName == 'self':
+                sect = 'Self'
             # Everything between the current section link and the end
             # of the <ol> tag.
             if _parseChr and sect == 'filmography':
@@ -597,16 +617,24 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
             else:
                 inisect = s.find('<a name="%s' % sect)
             if inisect != -1:
-                endsect = s[inisect:].find('</ol>')
+                endsect = s[inisect:].find('<div id="filmo-head-')
+                if endsect == -1:
+                    endsect = s[inisect:].find('<div class="article"')
                 if endsect != -1: raws = s[inisect:inisect+endsect]
-            if not raws: continue
-            mlist = _findBetween(raws, '<li>', ('</li>', '<br>', '<br/>'))
+            #if not raws: continue
+            mlist = _findBetween(raws, '<div class="filmo-row',
+                    ('<div class="clear"/>',))
             for m in mlist:
+                fCB = m.find('>')
+                if fCB != -1:
+                    m = m[fCB+1:].lstrip()
+                m = re_filmo_episodes.sub('', m)
                 # For every movie in the current section.
                 movieID = re_imdbID.findall(m)
                 if not movieID:
                     self._mobile_logger.debug('no movieID in %s', m)
                     continue
+                m = m.replace('<br/>', ' .... ', 1)
                 if not _parseChr:
                     chrIndx = m.find(' .... ')
                 else:
@@ -635,14 +663,22 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
                     if stendidx != -1:
                         status = _unHtml(m[stidx+3:stendidx])
                         m = m.replace(m[stidx+3:stendidx], '')
+                year = _findBetween(m, 'year_column">', '</span>', maxRes=1)
+                if year:
+                    year = year[0]
+                    m = m.replace('<span class="year_column">%s</span>' % year,
+                            '')
+                else:
+                    year = None
                 m = _unHtml(m)
                 if not m:
-                    self._mobile_logger.warn('no title fo rmovieID %s', movieID)
+                    self._mobile_logger.warn('no title for movieID %s', movieID)
                     continue
                 movie = build_movie(m, movieID=movieID, status=status,
                                     roleID=chids, modFunct=self._defModFunct,
                                     accessSystem=self.accessSystem,
-                                    _parsingCharacter=_parseChr)
+                                    _parsingCharacter=_parseChr, year=year)
+                sectName = sectName.split(':')[0]
                 r.setdefault(sectName, []).append(movie)
         # If available, take the always correct name from a form.
         itag = _getTagsWith(s, 'NAME="primary"', maxRes=1)
@@ -662,7 +698,7 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         return {'data': r, 'info sets': ('main', 'filmography')}
 
     def get_person_biography(self, personID):
-        cont = self._mretrieve(imdbURL_person_main % personID + 'bio')
+        cont = self._mretrieve(self.urls['person_main'] % personID + 'bio')
         d = {}
         spouses = _findBetween(cont, 'Spouse</h5>', ('</table>', '</dd>'),
                                 maxRes=1)
@@ -780,7 +816,7 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         return self.get_person_main(characterID, _parseChr=True)
 
     def get_character_biography(self, characterID):
-        cont = self._mretrieve(imdbURL_character_main % characterID + 'bio')
+        cont = self._mretrieve(self.urls['character_main'] % characterID + 'bio')
         d = {}
         intro = _findBetween(cont, '<div class="display">',
                             ('<span>', '<h4>'), maxRes=1)
@@ -788,10 +824,10 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
             intro = _unHtml(intro[0]).strip()
             if intro:
                 d['introduction'] = intro
-        bios = _findBetween(cont, '<div class="display">',
-                            '<div class="history">')
-        if bios:
-            bios = _findBetween(bios[0], '<h4>', ('<h4>', '</div>'))
+        tocidx = cont.find('<table id="toc..')
+        if tocidx != -1:
+            cont = cont[tocidx:]
+        bios = _findBetween(cont, '<h4>', ('<h4>', '</div>'))
         if bios:
             for bio in bios:
                 bio = bio.replace('</h4>', '::')
