@@ -3,7 +3,7 @@ parser.sql.alchemyadapter module (imdb.parser.sql package).
 
 This module adapts the SQLAlchemy ORM to the internal mechanism.
 
-Copyright 2008-2009 Davide Alberani <da@erlug.linux.it>
+Copyright 2008-2010 Davide Alberani <da@erlug.linux.it>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,19 +21,22 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
 import re
-import warnings
+import sys
+import logging
 from sqlalchemy import *
 from sqlalchemy import schema
 try: from sqlalchemy import exc # 0.5
 except ImportError: from sqlalchemy import exceptions as exc # 0.4
 
+_alchemy_logger = logging.getLogger('imdbpy.parser.sql.alchemy')
+
 try:
     import migrate.changeset
     HAS_MC = True
 except ImportError:
     HAS_MC = False
-    warnings.warn('Unable to import migrate.changeset: Foreign Keys will ' \
-                    'not be created.')
+    _alchemy_logger.warn('Unable to import migrate.changeset: Foreign ' \
+                         'Keys will not be created.')
 
 from imdb._exceptions import IMDbDataAccessError
 from dbschema import *
@@ -125,7 +128,7 @@ class QAdapter(object):
 
     def __getattr__(self, name):
         try: return getattr(self.table.c, self.colMap[name])
-        except KeyError, e: raise AttributeError, "unable to get '%s'" % name
+        except KeyError, e: raise AttributeError("unable to get '%s'" % name)
 
     def __repr__(self):
         return '<QAdapter(table=%s, colMap=%s) [id=%s]>' % \
@@ -147,7 +150,7 @@ class RowAdapter(object):
 
     def __getattr__(self, name):
         try: return getattr(self.row, self.colMap[name])
-        except KeyError, e: raise AttributeError, "unable to get '%s'" % name
+        except KeyError, e: raise AttributeError("unable to get '%s'" % name)
 
     def __setattr__(self, name, value):
         # FIXME: I can't even think about how much performances suffer,
@@ -291,7 +294,7 @@ class TableAdapter(object):
         try:
             return result[0]
         except KeyError:
-            raise NotFoundError, 'no data for ID %s' % theID
+            raise NotFoundError('no data for ID %s' % theID)
 
     def dropTable(self, checkfirst=True):
         """Drop the table."""
@@ -337,8 +340,8 @@ class TableAdapter(object):
         try:
             idx.create()
         except exc.OperationalError, e:
-            warnings.warn('Skipping creation of the %s.%s index: %s' %
-                            (self.sqlmeta.table, col.name, e))
+            _alchemy_logger.warn('Skipping creation of the %s.%s index: %s' %
+                                (self.sqlmeta.table, col.name, e))
 
     def addIndexes(self, ifNotExists=True):
         """Create all required indexes."""
@@ -481,6 +484,11 @@ def setConnection(uri, tables, encoding='utf8', debug=False):
     engine = create_engine(uri, **params)
     metadata.bind = engine
     eng_conn = engine.connect()
+    if uri.startswith('sqlite'):
+        major = sys.version_info[0]
+        minor = sys.version_info[1]
+        if major > 2 or (major == 2 and minor > 5):
+            eng_conn.connection.connection.text_factory = str
     # XXX: OH MY, THAT'S A MESS!
     #      We need to return a "connection" object, with the .dbName
     #      attribute set to the db engine name (e.g. "mysql"), .paramstyle
