@@ -3,7 +3,7 @@ parser.sql.objectadapter module (imdb.parser.sql package).
 
 This module adapts the SQLObject ORM to the internal mechanism.
 
-Copyright 2008-2009 Davide Alberani <da@erlug.linux.it>
+Copyright 2008-2010 Davide Alberani <da@erlug.linux.it>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,11 +20,16 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """
 
+import sys
+import logging
+
 from sqlobject import *
 from sqlobject.sqlbuilder import ISNULL, ISNOTNULL, AND, OR, IN, CONTAINSSTRING
 
 from dbschema import *
 
+_object_logger = logging.getLogger('imdbpy.parser.sql.object')
+
 
 # Maps our placeholders to SQLAlchemy's column types.
 MAP_COLS = {
@@ -55,9 +60,8 @@ def addIndexes(cls, ifNotExists=True):
     try:
         cls.createIndexes(ifNotExists)
     except dberrors.OperationalError, e:
-        import warnings
-        warnings.warn('Skipping creation of the %s.%s index: %s' %
-                        (cls.sqlmeta.table, col.name, e))
+        _object_logger.warn('Skipping creation of the %s.%s index: %s' %
+                            (cls.sqlmeta.table, col.name, e))
 addIndexes = classmethod(addIndexes)
 
 
@@ -180,6 +184,15 @@ def setConnection(uri, tables, encoding='utf8', debug=False):
         kw['charset'] = encoding
     conn = connectionForURI(uri, **kw)
     conn.debug = debug
+    # XXX: doesn't work and a work-around was put in imdbpy2sql.py;
+    #      is there any way to modify the text_factory parameter of
+    #      a SQLite connection?
+    #if uri.startswith('sqlite'):
+    #    major = sys.version_info[0]
+    #    minor = sys.version_info[1]
+    #    if major > 2 or (major == 2 and minor > 5):
+    #        sqliteConn = conn.getConnection()
+    #        sqliteConn.text_factory = str
     for table in tables:
         table.setConnection(conn)
         #table.sqlmeta.cacheValues = False
