@@ -3,7 +3,7 @@ utils module (imdb package).
 
 This module provides basic utilities for the imdb package.
 
-Copyright 2004-2009 Davide Alberani <da@erlug.linux.it>
+Copyright 2004-2012 Davide Alberani <da@erlug.linux.it>
                2009 H. Turgut Uyar <uyar@tekir.org>
 
 This program is free software; you can redistribute it and/or modify
@@ -24,24 +24,36 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 from __future__ import generators
 import re
 import string
+import logging
 from copy import copy, deepcopy
 from time import strptime, strftime
 
+from imdb import VERSION
+from imdb import linguistics
 from imdb._exceptions import IMDbParserError
 
+
+# Logger for imdb.utils module.
+_utils_logger = logging.getLogger('imdbpy.utils')
+
 # The regular expression for the "long" year format of IMDb, like
 # "(1998)" and "(1986/II)", where the optional roman number (that I call
 # "imdbIndex" after the slash is used for movies with the same title
 # and year of release.
 # XXX: probably L, C, D and M are far too much! ;-)
 re_year_index = re.compile(r'\(([0-9\?]{4}(/[IVXLCDM]+)?)\)')
+re_extended_year_index = re.compile(r'\((TV episode|TV Series|TV mini-series|TV|Video|Video Game)? ?((?:[0-9\?]{4})(?:-[0-9\?]{4})?)(?:/([IVXLCDM]+)?)?\)')
+re_remove_kind = re.compile(r'\((TV episode|TV Series|TV mini-series|TV|Video|Video Game)? ?')
 
 # Match only the imdbIndex (for name strings).
 re_index = re.compile(r'^\(([IVXLCDM]+)\)$')
 
+# Match things inside parentheses.
+re_parentheses = re.compile(r'(\(.*\))')
+
 # Match the number of episodes.
 re_episodes = re.compile('\s?\((\d+) episodes\)', re.I)
-re_episode_info = re.compile(r'{(.+?)?\s?(\([0-9\?]{4}-[0-9\?]{1,2}-[0-9\?]{1,2}\))?\s?(\(#[0-9]+\.[0-9]+\))?}')
+re_episode_info = re.compile(r'{\s*(.+?)?\s?(\([0-9\?]{4}-[0-9\?]{1,2}-[0-9\?]{1,2}\))?\s?(\(#[0-9]+\.[0-9]+\))?}')
 
 # Common suffixes in surnames.
 _sname_suffixes = ('de', 'la', 'der', 'den', 'del', 'y', 'da', 'van',
@@ -129,13 +141,17 @@ def analyze_name(name, canonical=None):
     res = {}
     imdbIndex = ''
     opi = name.rfind('(')
-    if opi != -1:
-        cpi = name.rfind(')')
-        if cpi > opi and re_index.match(name[opi:cpi+1]):
+    cpi = name.rfind(')')
+    # Strip  notes (but not if the name starts with a parenthesis).
+    if opi not in (-1, 0) and cpi > opi:
+        if re_index.match(name[opi:cpi+1]):
             imdbIndex = name[opi+1:cpi]
             name = name[:opi].rstrip()
+        else:
+            # XXX: for the birth and death dates case like " (1926-2004)"
+            name = re_parentheses.sub('', name).strip()
     if not name:
-        raise IMDbParserError, 'invalid name: "%s"' % original_n
+        raise IMDbParserError('invalid name: "%s"' % original_n)
     if canonical is not None:
         if canonical:
             name = canonicalName(name)
@@ -167,61 +183,20 @@ def build_name(name_dict, canonical=None):
     return name
 
 
-# List of articles.
-# XXX: Managing titles in a lot of different languages, a function to recognize
-# an initial article can't be perfect; sometimes we'll stumble upon a short
-# word that is an article in some language, but it's not in another; in these
-# situations we have to choose if we want to interpret this little word
-# as an article or not (remember that we don't know what the original language
-# of the title was).
-# Example: 'da' is an article in (I think) Dutch and it's used as an article
-# even in some American slangs.  Unfortunately it's also a preposition in
-# Italian, and it's widely used in Mandarin (for whatever it means!).
-# Running a script over the whole list of titles (and aliases), I've found
-# that 'da' is used as an article only 23 times, and as another thing 298
-# times, so I've decided to _always_ consider 'da' as a non article.
-#
-# Here is a list of words that are _never_ considered as articles, complete
-# with the cound of times they are used in a way or another:
-# 'en' (376 vs 594), 'to' (399 vs 727), 'as' (198 vs 276), 'et' (79 vs 99),
-# 'des' (75 vs 150), 'al' (78 vs 304), 'ye' (14 vs 70),
-# 'da' (23 vs 298), "'n" (8 vs 12)
-#
-# I've left in the list 'i' (1939 vs 2151) and 'uno' (52 vs 56)
-# I'm not sure what '-al' is, and so I've left it out...
-#
-# List of articles in utf-8 encoding:
-_articles = ('the', 'la', 'a', 'die', 'der', 'le', 'el',
-            "l'", 'il', 'das', 'les', 'i', 'o', 'ein', 'un', 'de', 'los',
-            'an', 'una', 'las', 'eine', 'den', 'het', 'gli', 'lo', 'os',
-            'ang', 'oi', 'az', 'een', 'ha-', 'det', 'ta', 'al-',
-            'mga', "un'", 'uno', 'ett', 'dem', 'egy', 'els', 'eines',
-            '\xc3\x8f', '\xc3\x87', '\xc3\x94\xc3\xaf', '\xc3\x8f\xc3\xa9')
+# XXX: here only for backward compatibility.  Find and remove any dependency.
+_articles = linguistics.GENERIC_ARTICLES
+_unicodeArticles = linguistics.toUnicode(_articles)
+articlesDicts = linguistics.articlesDictsForLang(None)
+spArticles = linguistics.spArticlesForLang(None)
 
-_unicodeArticles = tuple([art.decode('utf_8') for art in _articles])
-
-# Articles in a dictionary.
-_articlesDict = dict([(x, x) for x in _articles])
-# Unicode version.
-_unicodeArticlesDict = dict([(x, x) for x in _unicodeArticles])
-_spArticles = []
-# Variations with a trailing space.
-for article in _articles:
-    if article[-1] not in ("'", '-'): article += ' '
-    _spArticles.append(article)
-_spUnicodeArticles = []
-for article in _unicodeArticles:
-    if article[-1] not in ("'", '-'): article += u' '
-    _spUnicodeArticles.append(article)
-
-articlesDicts = (_articlesDict, _unicodeArticlesDict)
-spArticles = (_spArticles, _spUnicodeArticles)
-
-def canonicalTitle(title):
+def canonicalTitle(title, lang=None):
     """Return the title in the canonic format 'Movie Title, The';
     beware that it doesn't handle long imdb titles, but only the
-    title portion, without year[/imdbIndex] or special markup."""
+    title portion, without year[/imdbIndex] or special markup.
+    The 'lang' argument can be used to specify the language of the title.
+    """
     isUnicode = isinstance(title, unicode)
+    articlesDicts = linguistics.articlesDictsForLang(lang)
     try:
         if title.split(', ')[-1].lower() in articlesDicts[isUnicode]:
             return title
@@ -232,11 +207,13 @@ def canonicalTitle(title):
     else:
         _format = '%s, %s'
     ltitle = title.lower()
+    spArticles = linguistics.spArticlesForLang(lang)
     for article in spArticles[isUnicode]:
         if ltitle.startswith(article):
             lart = len(article)
             title = _format % (title[lart:], title[:lart])
-            if article[-1] == ' ': title = title[:-1]
+            if article[-1] == ' ':
+                title = title[:-1]
             break
     ## XXX: an attempt using a dictionary lookup.
     ##for artSeparator in (' ', "'", '-'):
@@ -251,15 +228,19 @@ def canonicalTitle(title):
     ##        break
     return title
 
-def normalizeTitle(title):
+def normalizeTitle(title, lang=None):
     """Return the title in the normal "The Title" format;
     beware that it doesn't handle long imdb titles, but only the
-    title portion, without year[/imdbIndex] or special markup."""
+    title portion, without year[/imdbIndex] or special markup.
+    The 'lang' argument can be used to specify the language of the title.
+    """
     isUnicode = isinstance(title, unicode)
     stitle = title.split(', ')
+    articlesDicts = linguistics.articlesDictsForLang(lang)
     if len(stitle) > 1 and stitle[-1].lower() in articlesDicts[isUnicode]:
         sep = ' '
-        if stitle[-1][-1] in ("'", '-'): sep = ''
+        if stitle[-1][-1] in ("'", '-'):
+            sep = ''
         if isUnicode:
             _format = u'%s%s%s'
             _joiner = u', '
@@ -284,7 +265,7 @@ def _split_series_episode(title):
         if begin_eps == -1: return '', ''
         series_title = title[:begin_eps].rstrip()
         # episode_or_year is returned with the {...}
-        episode_or_year = title[begin_eps:]
+        episode_or_year = title[begin_eps:].strip()
         if episode_or_year[:12] == '{SUSPENDED}}': return '', ''
     # XXX: works only with tv series; it's still unclear whether
     #      IMDb will support episodes for tv mini series and tv movies...
@@ -329,6 +310,7 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
 
     raise an IMDbParserError exception if the title is not valid.
     """
+    # XXX: introduce the 'lang' argument?
     if canonical is not None:
         canonicalSeries = canonicalEpisode = canonical
     original_t = title
@@ -348,6 +330,7 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
             if match:
                 # Episode title, original air date and #season.episode
                 episode_or_year, oad, sen = match[0]
+                episode_or_year = episode_or_year.strip()
                 if not oad:
                     # No year, but the title is something like (2005-04-12)
                     if episode_or_year and episode_or_year[0] == '(' and \
@@ -384,7 +367,8 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
                 try: epn = int(epn)
                 except: pass
                 episode_d['season'] = seas
-                episode_d['episode'] = epn
+                if epn:
+                    episode_d['episode'] = epn
         return episode_d
     # First of all, search for the kind of show.
     # XXX: Number of entries at 17 Apr 2008:
@@ -402,6 +386,9 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
     elif title.endswith('(V)'):
         kind = u'video movie'
         title = title[:-3].rstrip()
+    elif title.endswith('(video)'):
+        kind = u'video movie'
+        title = title[:-7].rstrip()
     elif title.endswith('(mini)'):
         kind = u'tv mini series'
         title = title[:-6].rstrip()
@@ -410,6 +397,24 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
         title = title[:-4].rstrip()
     # Search for the year and the optional imdbIndex (a roman number).
     yi = re_year_index.findall(title)
+    if not yi:
+        yi = re_extended_year_index.findall(title)
+        if yi:
+            yk, yiy, yii = yi[-1]
+            yi = [(yiy, yii)]
+            if yk == 'TV episode':
+                kind = u'episode'
+            elif yk == 'TV':
+                kind = u'tv movie'
+            elif yk == 'TV Series':
+                kind = u'tv series'
+            elif yk == 'Video':
+                kind = u'video movie'
+            elif yk == 'TV mini-series':
+                kind = u'tv mini series'
+            elif yk == 'Video Game':
+                kind = u'video game'
+            title = re_remove_kind.sub('(', title)
     if yi:
         last_yi = yi[-1]
         year = last_yi[0]
@@ -425,8 +430,11 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
         if not kind:
             kind = u'tv series'
         title = title[1:-1].strip()
+    elif title.endswith('(TV series)'):
+        kind = u'tv series'
+        title = title[:-11].rstrip()
     if not title:
-        raise IMDbParserError, 'invalid title: "%s"' % original_t
+        raise IMDbParserError('invalid title: "%s"' % original_t)
     if canonical is not None:
         if canonical:
             title = canonicalTitle(title)
@@ -437,6 +445,9 @@ def analyze_title(title, canonical=None, canonicalSeries=None,
     result['title'] = title
     result['kind'] = kind or u'movie'
     if year and year != '????':
+        if '-' in year:
+            result['series years'] = year
+            year = year[:4]
         try:
             result['year'] = int(year)
         except (TypeError, ValueError):
@@ -477,7 +488,8 @@ def _convertTime(title, fromPTDFtoWEB=1, _emptyString=u''):
 
 
 def build_title(title_dict, canonical=None, canonicalSeries=None,
-                canonicalEpisode=None, ptdf=0, _doYear=1, _emptyString=u''):
+                canonicalEpisode=None, ptdf=0, lang=None, _doYear=1,
+                _emptyString=u''):
     """Given a dictionary that represents a "long" IMDb title,
     return a string.
 
@@ -485,6 +497,8 @@ def build_title(title_dict, canonical=None, canonicalSeries=None,
     If canonical is True, the title is converted to canonical style.
     If canonical is False, the title is converted to normal format.
 
+    lang can be used to specify the language of the title.
+
     If ptdf is true, the plain text data files format is used.
     """
     if canonical is not None:
@@ -536,9 +550,9 @@ def build_title(title_dict, canonical=None, canonicalSeries=None,
     if not title: return _emptyString
     if canonical is not None:
         if canonical:
-            title = canonicalTitle(title)
+            title = canonicalTitle(title, lang=lang)
         else:
-            title = normalizeTitle(title)
+            title = normalizeTitle(title, lang=lang)
     if pre_title:
         title = '%s %s' % (pre_title, title)
     if kind in (u'tv series', u'tv mini series'):
@@ -595,7 +609,7 @@ def analyze_company_name(name, stripNotes=False):
             country = name[idx:]
             name = name[:idx].rstrip()
     if not name:
-        raise IMDbParserError, 'invalid name: "%s"' % o_name
+        raise IMDbParserError('invalid name: "%s"' % o_name)
     result = {'name': name}
     if country:
         result['country'] = country
@@ -672,6 +686,14 @@ def cmpMovies(m1, m2):
     m2i = m2.get('imdbIndex', _last)
     if m1i > m2i: return -1
     if m1i < m2i: return 1
+    m1id = getattr(m1, 'movieID', None)
+    # Introduce this check even for other comparisons functions?
+    # XXX: is it safe to check without knowning the data access system?
+    #      probably not a great idea.  Check for 'kind', instead?
+    if m1id is not None:
+        m2id = getattr(m2, 'movieID', None)
+        if m1id > m2id: return -1
+        elif m1id < m2id: return 1
     return 0
 
 
@@ -803,7 +825,9 @@ class RolesList(list):
 
 
 # Replace & with &amp;, but only if it's not already part of a charref.
-_re_amp = re.compile(r'(&)(?!\w+;)', re.I)
+#_re_amp = re.compile(r'(&)(?!\w+;)', re.I)
+#_re_amp = re.compile(r'(?<=\W)&(?=[^a-zA-Z0-9_#])')
+_re_amp = re.compile(r'&(?![^a-zA-Z0-9_#]{1,5};)')
 
 def escape4xml(value):
     """Escape some chars that can't be present in a XML value."""
@@ -835,6 +859,11 @@ def _refsToReplace(value, modFunct, titlesRefs, namesRefs, charactersRefs):
             # modFunct is modified.
             goodValue = modFunct(refTemplate % theRef, titlesRefs, namesRefs,
                                 charactersRefs)
+            # Prevents problems with crap in plain text data files.
+            # We should probably exclude invalid chars and string that
+            # are too long in the re_*Ref expressions.
+            if '_' in goodValue or len(goodValue) > 128:
+                continue
             toReplace = escape4xml(goodValue)
             # Only the 'value' portion is replaced.
             replaceWith = goodValue.replace(theRef, escape4xml(theRef))
@@ -926,21 +955,21 @@ def _tag4TON(ton, addAccessSystem=False, _containerOnly=False):
 
 
 TAGS_TO_MODIFY = {
-    'movie.parents-guide': ('item', 'title'),
-    'movie.number-of-votes': ('item', 'title'),
-    'movie.soundtrack.item': ('item', 'title'),
-    'movie.quotes': ('quote', None),
-    'movie.quotes.quote': ('line', None),
-    'movie.demographic': ('item', 'title'),
-    'movie.episodes': ('season', 'number'),
-    'movie.episodes.season': ('episode', 'number'),
-    'person.merchandising-links':  ('item', 'title'),
-    'person.genres':  ('item', 'title'),
-    'person.quotes':  ('quote', None),
-    'person.keywords':  ('item', 'title'),
-    'character.quotes': ('item', 'title'),
-    'character.quotes.item': ('quote', None),
-    'character.quotes.item.quote': ('line', None)
+    'movie.parents-guide': ('item', True),
+    'movie.number-of-votes': ('item', True),
+    'movie.soundtrack.item': ('item', True),
+    'movie.quotes': ('quote', False),
+    'movie.quotes.quote': ('line', False),
+    'movie.demographic': ('item', True),
+    'movie.episodes': ('season', True),
+    'movie.episodes.season': ('episode', True),
+    'person.merchandising-links':  ('item', True),
+    'person.genres':  ('item', True),
+    'person.quotes':  ('quote', False),
+    'person.keywords':  ('item', True),
+    'character.quotes': ('item', True),
+    'character.quotes.item': ('quote', False),
+    'character.quotes.item.quote': ('line', False)
     }
 
 _allchars = string.maketrans('', '')
@@ -951,32 +980,38 @@ def _tagAttr(key, fullpath):
     """Return a tuple with a tag name and a (possibly empty) attribute,
     applying the conversions specified in TAGS_TO_MODIFY and checking
     that the tag is safe for a XML document."""
-    value_attr = None
-    attrs = u''
+    attrs = {}
+    _escapedKey = escape4xml(key)
     if fullpath in TAGS_TO_MODIFY:
-        tagName, value_attr = TAGS_TO_MODIFY[fullpath]
+        tagName, useTitle = TAGS_TO_MODIFY[fullpath]
+        if useTitle:
+            attrs['key'] = _escapedKey
     elif not isinstance(key, unicode):
         if isinstance(key, str):
             tagName = unicode(key, 'ascii', 'ignore')
         else:
+            strType = str(type(key)).replace("<type '", "").replace("'>", "")
+            attrs['keytype'] = strType
             tagName = unicode(key)
     else:
         tagName = key
-    tagName = tagName.lower().replace(' ', '-')
+    if isinstance(key, int):
+        attrs['keytype'] = 'int'
     origTagName = tagName
+    tagName = tagName.lower().replace(' ', '-')
     tagName = str(tagName).translate(_allchars, _keepchars)
-    if (not tagName) or tagName[0].isdigit() or tagName[0] == '-' or \
-            origTagName != tagName:
+    if origTagName != tagName:
+        if 'key' not in attrs:
+            attrs['key'] = _escapedKey
+    if (not tagName) or tagName[0].isdigit() or tagName[0] == '-':
         # This is a fail-safe: we should never be here, since unpredictable
         # keys must be listed in TAGS_TO_MODIFY.
-        # This will break the DTD/schema, but at least it will produce a
-        # valid XML.
-        #print 'ERROR - INVALID TAG: %s [%s]' % (escape4xml(key), fullpath)
+        # This will proably break the DTD/schema, but at least it will
+        # produce a valid XML.
         tagName = 'item'
-        value_attr = 'key'
-    if value_attr is not None:
-        attrs = u'%s="%s"' % (value_attr, escape4xml(key))
-    return tagName, attrs
+        _utils_logger.error('invalid tag: %s [%s]' % (_escapedKey, fullpath))
+        attrs['key'] = _escapedKey
+    return tagName, u' '.join([u'%s="%s"' % i for i in attrs.items()])
 
 
 def _seq2xml(seq, _l=None, withRefs=False, modFunct=None,
@@ -988,6 +1023,7 @@ def _seq2xml(seq, _l=None, withRefs=False, modFunct=None,
         _l = []
     if isinstance(seq, dict):
         for key in seq:
+            value = seq[key]
             if isinstance(key, _Container):
                 # Here we're assuming that a _Container is never a top-level
                 # key (otherwise we should handle key2infoset).
@@ -1001,10 +1037,14 @@ def _seq2xml(seq, _l=None, withRefs=False, modFunct=None,
                     openTag += ' %s' % attrs
                 if _topLevel and key2infoset and key in key2infoset:
                     openTag += u' infoset="%s"' % key2infoset[key]
+                if isinstance(value, int):
+                    openTag += ' type="int"'
+                elif isinstance(value, float):
+                    openTag += ' type="float"'
                 openTag += u'>'
                 closeTag = u'</%s>' % tagName
             _l.append(openTag)
-            _seq2xml(seq[key], _l, withRefs, modFunct, titlesRefs,
+            _seq2xml(value, _l, withRefs, modFunct, titlesRefs,
                     namesRefs, charactersRefs, _topLevel=False,
                     fullpath='%s.%s' % (fullpath, tagName))
             _l.append(closeTag)
@@ -1013,7 +1053,7 @@ def _seq2xml(seq, _l=None, withRefs=False, modFunct=None,
         beginTag = u'<%s' % tagName
         if attrs:
             beginTag += u' %s' % attrs
-        beginTag += u'>'
+        #beginTag += u'>'
         closeTag = u'</%s>' % tagName
         for item in seq:
             if isinstance(item, _Container):
@@ -1022,7 +1062,13 @@ def _seq2xml(seq, _l=None, withRefs=False, modFunct=None,
                          fullpath='%s.%s' % (fullpath,
                                     item.__class__.__name__.lower()))
             else:
-                _l.append(beginTag)
+                openTag = beginTag
+                if isinstance(item, int):
+                    openTag += ' type="int"'
+                elif isinstance(item, float):
+                    openTag += ' type="float"'
+                openTag += u'>'
+                _l.append(openTag)
                 _seq2xml(item, _l, withRefs, modFunct, titlesRefs,
                         namesRefs, charactersRefs, _topLevel=False,
                         fullpath='%s.%s' % (fullpath, tagName))
@@ -1040,15 +1086,17 @@ def _seq2xml(seq, _l=None, withRefs=False, modFunct=None,
     return _l
 
 
-# XXX: the path is still to be decided (and there's no file, actually)
 _xmlHead = u"""<?xml version="1.0"?>
-<!DOCTYPE %s SYSTEM "http://imdbpy.sf.net/dtd/imdbpy41.dtd">
+<!DOCTYPE %s SYSTEM "http://imdbpy.sf.net/dtd/imdbpy{VERSION}.dtd">
 
 """
+_xmlHead = _xmlHead.replace('{VERSION}',
+        VERSION.replace('.', '').split('dev')[0][:2])
+
 
 class _Container(object):
     """Base class for Movie, Person, Character and Company classes."""
-     # The default sets of information retrieved.
+    # The default sets of information retrieved.
     default_info = ()
 
     # Aliases for some not-so-intuitive keys.
@@ -1060,6 +1108,9 @@ class _Container(object):
     # Function used to compare two instances of this class.
     cmpFunct = None
 
+    # Regular expression used to build the 'full-size (headshot|cover url)'.
+    _re_fullsizeURL = re.compile(r'\._V1\._SX(\d+)_SY(\d+)_')
+
     def __init__(self, myID=None, data=None, notes=u'',
                 currentRole=u'', roleID=None, roleIsPerson=False,
                 accessSystem=None, titlesRefs=None, namesRefs=None,
@@ -1283,7 +1334,7 @@ class _Container(object):
 
     def getID(self):
         """Return movieID, personID, characterID or companyID."""
-        raise NotImplementedError, 'override this method'
+        raise NotImplementedError('override this method')
 
     def __cmp__(self, other):
         """Compare two Movie, Person, Character or Company objects."""
@@ -1317,9 +1368,10 @@ class _Container(object):
         """Number of items in the data dictionary."""
         return len(self.data)
 
-    def getAsXML(self, key):
+    def getAsXML(self, key, _with_add_keys=True):
         """Return a XML representation of the specified key, or None
-        if empty."""
+        if empty.  If _with_add_keys is False, dinamically generated
+        keys are excluded."""
         # Prevent modifyStrings in __getitem__ to be called; if needed,
         # it will be called by the _normalizeValue function.
         origModFunct = self.modFunct
@@ -1329,6 +1381,9 @@ class _Container(object):
         #      a DTD valid tag, and not something that can be only in
         #      the keys_alias map).
         key = self.keys_alias.get(key, key)
+        if (not _with_add_keys) and  (key in self._additional_keys()):
+            self.modFunct = origModFunct
+            return None
         try:
             withRefs = False
             if key in self.keys_tomodify and \
@@ -1348,13 +1403,14 @@ class _Container(object):
         finally:
             self.modFunct = origModFunct
 
-    def asXML(self):
-        """Return a XML representation of the whole object."""
+    def asXML(self, _with_add_keys=True):
+        """Return a XML representation of the whole object.
+        If _with_add_keys is False, dinamically generated keys are excluded."""
         beginTag, endTag = _tag4TON(self, addAccessSystem=True,
                                     _containerOnly=True)
         resList = [beginTag]
         for key in self.keys():
-            value = self.getAsXML(key)
+            value = self.getAsXML(key, _with_add_keys=_with_add_keys)
             if not value:
                 continue
             resList.append(value)
@@ -1385,7 +1441,7 @@ class _Container(object):
                 import warnings
                 warnings.warn('RuntimeError in '
                         "imdb.utils._Container.__getitem__; if it's not "
-                        "a recursion limit exceeded or we're not running "
+                        "a recursion limit exceeded and we're not running "
                         "in a Symbian environment, it's a bug:\n%s" % e)
         return rawData
 
@@ -1453,14 +1509,14 @@ class _Container(object):
 
     def __repr__(self):
         """String representation of an object."""
-        raise NotImplementedError, 'override this method'
+        raise NotImplementedError('override this method')
 
     def __str__(self):
         """Movie title or person name."""
-        raise NotImplementedError, 'override this method'
+        raise NotImplementedError('override this method')
 
     def __contains__(self, key):
-        raise NotImplementedError, 'override this method'
+        raise NotImplementedError('override this method')
 
     def append_item(self, key, item):
         """The item is appended to the list identified by the given key."""
@@ -1476,7 +1532,7 @@ class _Container(object):
         return 0
 
     def __deepcopy__(self, memo):
-        raise NotImplementedError, 'override this method'
+        raise NotImplementedError('override this method')
 
     def copy(self):
         """Return a deep copy of the object itself."""
@@ -1491,7 +1547,6 @@ def flatten(seq, toDescend=(list, dict, tuple), yieldDictKeys=0,
     items of the given type(s) are yielded."""
     if scalar is None or isinstance(seq, scalar):
         yield seq
-    #else:
     if isinstance(seq, toDescend):
         if isinstance(seq, (dict, _Container)):
             if yieldDictKeys:
